@@ -93,12 +93,12 @@ function(web, H2_integer=TRUE){
                    thrd=which(difexp[scnd,]==min(difexp[scnd,]))[1]
                    newmx[scnd,thrd] = newmx[scnd,thrd] - 1
                    newmx[throw,thrd] = newmx[throw,thrd] + 1
-                  }
-      		}
+          }
+      }
       		newweb <- newmx
-  		}     # end Hmaxfind
+  }     # end Hmaxfind
 		#  Hmax=H2(newmx)    
-	}
+	} # end else-part of initial exexpec
     H2_max <- -sum(newweb/tot*log(newweb/tot), na.rm=TRUE)   
    
     
@@ -109,8 +109,8 @@ function(web, H2_integer=TRUE){
     # maximum of aggregation possible.
     newweb <- matrix(0,length(rs),length(cs))
     rsrest=rs; csrest=cs
-    while (sum(rsrest)!=0) {
-        newweb[which(rsrest==max(rsrest))[1],which(csrest==max(csrest))[1]]=min(c(max(rsrest),max(csrest)))
+    while (round(sum(rsrest), 10) != 0) { ## Bob O'Hara's suggestion: while (isTRUE(all.equal(sum(rsrest),0))) {
+        newweb[which(rsrest==max(rsrest))[1],which(csrest==max(csrest))[1]] = min(c(max(rsrest),max(csrest)))
         rsrest=rs-rowSums(newweb)
         csrest=cs-colSums(newweb)
     }
